#include "conrt.h"

int Socket(int family, int type, int protocol){
    int             n;

    if ((n = socket(family, type, protocol)) < 0)
	err_sys("socket error");
    return(n);
}

void *Malloc(size_t size){
    void *ptr;

    if ((ptr = malloc(size)) == NULL)
	err_sys("malloc error");
    return(ptr);
}

void *Reallocf(void *ptr,size_t size){
    void *newptr;

    if ((newptr = reallocf(ptr,size)) == NULL)
	err_sys("reallocf error");
    return(newptr);
}

void *Calloc(size_t number,size_t size){
    void *newptr;

    if ((newptr = calloc(number,size)) == NULL)
	err_sys("calloc error");
    return(newptr);
}

void Write(int fd, void *ptr, size_t nbytes){
        if (write(fd, ptr, nbytes) != nbytes)
                err_sys("write error");
}

ssize_t Read(int fd, void *ptr, size_t nbytes){
        ssize_t         n;
        
        if ( (n = read(fd, ptr, nbytes)) == -1)
                err_sys("read error");
        return(n);
}

int Fork() {
    int pid;
    if (( pid=fork())<0) 
	err_sys("Fork failed");
    return pid;
}

int Ether_aton(char *a, struct ether_addr *n) {
	struct ether_addr *ea;

	if ((ea = ether_aton(a)) == NULL) {
		err_msg("invalid Ethernet address '%s'", a);
		return (1);
	}
	*n = *ea;
	return (0);
}

int Kevent(int kq, const struct kevent *cl, int nc, struct kevent *el, int nev, const struct timespec *to){
    int n;

    if ((n=kevent(kq,cl,nc,el,nev,to)) <0 )
	err_sys("kqueue adding event failed");
    return n;
}

void *Get_Sysctl(int *name, u_int namelen,size_t *needed){
    int errnumber=1,errorprevious=0;
    int e_get_sysctl=ERROR_GET_SYSCTL;
    void *buf;

    while (errnumber>errorprevious) {
        errorprevious = errnumber;
        if  (sysctl(name, namelen, NULL, needed, NULL, 0) < 0) {
            err_msg("sysctl-estimate error");
            errnumber++;
            if (errnumber>e_get_sysctl) {
                return NULL;
            }
        }
        buf = Malloc(*needed);
        if (sysctl(name, 6, buf, needed, NULL, 0) <0) {
            err_msg("actual retrival error");
            errnumber++;
            free(buf);
            if (errnumber>e_get_sysctl) {
		return NULL;
            }
        }
    }
    return buf;
}